Plugin: JS9Cmaps

### Create Colormaps

The Colormaps plugin allows you to create compatible colormaps using a base color or an existing colormap. You can choose the number of colormaps to create, the algorithm used to create the new colormaps, and whether to apply them to existing images.

In order to give more control over colormap creation, the plugin allows you to specify a number of slices into which the 360 degree colorwheel will be divided, starting with the base color. The n created colormaps are then assigned to the first n slices of the colorwheel. For example, if you choose to create three slices and three colormaps, each colormap will be separated from the others by 120 degrees (1/3 of the colorwheel). If you create six slices and three colormaps, each colormap will be separated by 60 degrees (1/6 of the colorwheel), starting from the base color.

The algorithms for generating new colormaps are:

- equidistant: colormaps are created so that they are equidistant around the colorwheel. For example, when creating three colormaps from three slices, starting with a red base, the three colors used for the colormaps will be at 0, 120, and 240 degrees around the colorwheel (i.e. red, green, and blue).
- analogous: create groups of colors around the colorwheel (i.e., generally closer than equidistant). For example, red, orange, and red-orange are analogous colors. Choose three or more colormaps.

There are many, many articles on the net describing colors and their compatibility. Just search for "colorwheel", "color theory", or "compatible colors", etc.

When the color picker is used to select a base color, new colors are chosen from this base color to generate monochromatic colormaps. When an existing colormap is used, each inflection point of the colormap generates new colors, which then are combined into new colormaps.

By default, the color picker is the HTML5 color picker implemented within the browser. These internal color pickers generally have several nice ways to choose a color. If the browser does not support an internal color picker (e.g. Safari 11, even though the Mac OSX supports a great color picker!), a simplified color picker is used instead. Note that the HTML5 color picker is a bit quirky: it remains displayed when the page is unloaded or reloaded, even though it becomes detached from the new page. You must always exit the HTML5 color picker by clicking its exit button.

The generated colormaps are added to the Color menu in the more colormaps ... submenu. If you use the color picker to choose a base color, the colormaps are named "[id]_1", [id]_2", etc., where [id] is the id of the JS9 display (e.g. "JS9"). If you use an existing colormap, the new colormaps are called "[cname]_1", [cname]_2", etc., where [cname] is the name of the original colormap.

Colormaps can be assigned to images by clicking the button to the left of the image name. The colormap assignments are made in stacking order, which you can change by dragging an image into the appropriate place on the stack.

Note that the parameters of each colormap plugin instance can be controlled independently, and that each instance allows you to assign colormaps to any image, regardless of its parent display. This means, for example, that you can load three images into separate displays and change their colormaps simultaneously.